	.file	"overflow.c"
	.text
	.p2align 4,,15
.globl gets
	.type	gets, @function
gets:
	pushl	%ebp
	movl	%esp, %ebp
	pushl	%esi
	pushl	%ebx
	subl	$16, %esp
	movl	8(%ebp), %esi
	movl	%esi, %ebx
	jmp	.L2
	.p2align 4,,7
.L8:
	cmpl	$-1, %eax
	je	.L3
	movb	%al, (%ebx)
	incl	%ebx
.L2:
	movl	stdin, %eax
	movl	%eax, (%esp)
	call	_IO_getc
	cmpl	$10, %eax
	jne	.L8
.L3:
	xorl	%edx, %edx
	incl	%eax
	movb	$0, (%ebx)
	je	.L1
	movl	%esi, %edx
.L1:
	addl	$16, %esp
	movl	%edx, %eax
	popl	%ebx
	popl	%esi
	leave
	ret
	.size	gets, .-gets
	.p2align 4,,15
.globl echo
	.type	echo, @function
echo:
	pushl	%ebp
	movl	%esp, %ebp
	pushl	%ebx
	leal	-8(%ebp), %ebx
	subl	$20, %esp
	movl	%ebx, (%esp)
	call	gets
	movl	%ebx, (%esp)
	call	puts
	addl	$20, %esp
	popl	%ebx
	leave
	ret
	.size	echo, .-echo
	.p2align 4,,15
.globl echosafe
	.type	echosafe, @function
echosafe:
	pushl	%ebp
	movl	%esp, %ebp
	pushl	%ebx
	leal	-8(%ebp), %ebx
	subl	$20, %esp
	movl	stdin, %eax
	movl	%ebx, (%esp)
	movl	$4, 4(%esp)
	movl	%eax, 8(%esp)
	call	fgets
	movl	stdout, %eax
	movl	%ebx, (%esp)
	movl	%eax, 4(%esp)
	call	fputs
	addl	$20, %esp
	popl	%ebx
	leave
	ret
	.size	echosafe, .-echosafe
	.p2align 4,,15
.globl main
	.type	main, @function
main:
	pushl	%ebp
	movl	%esp, %ebp
	subl	$8, %esp
	andl	$-16, %esp
	subl	$16, %esp
.L12:
	call	echo
	call	echo
	jmp	.L12
	.size	main, .-main
	.section	.note.GNU-stack,"",@progbits
	.ident	"GCC: (GNU) 3.4.2 20041017 (Red Hat 3.4.2-6.fc3)"
