	.file	"stack.c"
	.text
.globl cons_
	.type	cons_, @function
cons_:
	pushl	%ebp
	movl	%esp, %ebp
	subl	$8, %esp
	movl	8(%ebp), %eax
	movl	%eax, -8(%ebp)
	movl	12(%ebp), %eax
	movl	%eax, -4(%ebp)
	leal	-8(%ebp), %eax
	leave
	ret
	.size	cons_, .-cons_
.globl cons
	.type	cons, @function
cons:
	pushl	%ebp
	movl	%esp, %ebp
	subl	$8, %esp
	movl	$8, (%esp)
	call	malloc
	movl	%eax, -4(%ebp)
	movl	-4(%ebp), %edx
	movl	8(%ebp), %eax
	movl	%eax, (%edx)
	movl	-4(%ebp), %edx
	movl	12(%ebp), %eax
	movl	%eax, 4(%edx)
	movl	-4(%ebp), %eax
	leave
	ret
	.size	cons, .-cons
	.section	.rodata
.LC0:
	.string	"%d %d\n"
	.text
.globl main
	.type	main, @function
main:
	pushl	%ebp
	movl	%esp, %ebp
	subl	$24, %esp
	andl	$-16, %esp
	movl	$0, %eax
	addl	$15, %eax
	addl	$15, %eax
	shrl	$4, %eax
	sall	$4, %eax
	subl	%eax, %esp
	movl	$0, 4(%esp)
	movl	$2, (%esp)
	call	cons_
	movl	%eax, 4(%esp)
	movl	$1, (%esp)
	call	cons_
	movl	%eax, -4(%ebp)
	movl	-4(%ebp), %eax
	movl	4(%eax), %eax
	movl	(%eax), %eax
	movl	%eax, 8(%esp)
	movl	-4(%ebp), %eax
	movl	(%eax), %eax
	movl	%eax, 4(%esp)
	movl	$.LC0, (%esp)
	call	printf
	movl	$0, 4(%esp)
	movl	$2, (%esp)
	call	cons
	movl	%eax, 4(%esp)
	movl	$1, (%esp)
	call	cons
	movl	%eax, -4(%ebp)
	movl	-4(%ebp), %eax
	movl	4(%eax), %eax
	movl	(%eax), %eax
	movl	%eax, 8(%esp)
	movl	-4(%ebp), %eax
	movl	(%eax), %eax
	movl	%eax, 4(%esp)
	movl	$.LC0, (%esp)
	call	printf
	movl	$0, (%esp)
	call	exit
	.size	main, .-main
	.section	.note.GNU-stack,"",@progbits
	.ident	"GCC: (GNU) 3.4.2 20041017 (Red Hat 3.4.2-6.fc3)"
